@@ -101,7 +101,7 @@ def create_push_github_repository(
         # git commit
         log.debug("git commit")
         cloned_repo.index.commit(
-            f"Created {creator_ctx.project_slug} with {creator_ctx.template_handle} "
+            f"Create {creator_ctx.project_slug} with {creator_ctx.template_handle} "
             f'template of version {creator_ctx.template_version.replace("# <<COOKIETEMPLE_NO_BUMP>>", "")} using cookietemple.'
         )
 
@@ -264,6 +264,12 @@ def prompt_github_repo(dot_cookietemple: Optional[dict]) -> Tuple[bool, bool, bo
             if is_github_org
             else ""
         )
+        console.print(
+            "[bold yellow]Be aware that cookietemple runs github actions for various Python versions (see noxfile.py. "
+            "Private projects may be run out of build minutes in a matter of hours when "
+            " there is a lot activity or Dependabot is enabled."
+        )
+
         private = cookietemple_questionary_or_dot_cookietemple(
             function="confirm", question="Do you want your repository to be private?", default="No"  # type: ignore
         )
@@ -467,5 +473,5 @@ def is_git_repo(path: Path) -> bool:
     try:
         _ = Repo(path).git_dir
         return True
-    except exc.InvalidGitRepositoryError:
+    except exc.InvalidGitRepositoryError:  # type: ignore[misc]
         return False
