@@ -74,7 +74,7 @@ class TemplateCreator:
             fix_short_title_underline(f"{project_path}/docs/index.rst")
 
         # Lint the project to verify that the new template adheres to all standards
-        lint_project(project_path, is_create=True, skip_external=False)
+        lint_project(project_path)
 
         if self.creator_ctx.is_github_repo and not dot_cookietemple:
             # rename the currently created template to a temporary name, create Github repo, push, remove temporary template
@@ -351,7 +351,11 @@ class TemplateCreator:
         # delete the tmp cookiecuttered common files directory
         log.debug("Delete common files directory.")
         delete_dir_tree(Path(f"{Path.cwd()}/common_files_util"))
-        shutil.rmtree(dirpath)
+        try:
+            shutil.rmtree(dirpath)
+        except PermissionError:
+            # If deleting these temporary files fails, fail silently (#748)
+            pass
         # change to recent cwd so lint etc can run properly
         os.chdir(str(cwd_project))
 
