@@ -10,7 +10,7 @@ class GuiJavaLint(TemplateLinter, metaclass=GetLintingFunctionsMeta):
     def __init__(self, path):
         super().__init__(path)
 
-    def lint(self, skip_external):
+    def lint(self):
         super().lint_project(self, self.methods)
 
     def check_sync_section(self) -> bool:
