@@ -1,10 +1,6 @@
 import os
-from subprocess import Popen
 from typing import List
 
-from rich import print
-
-from cookietemple.custom_cli.questionary import cookietemple_questionary_or_dot_cookietemple
 from cookietemple.lint.template_linter import ConfigLinter, GetLintingFunctionsMeta, TemplateLinter, files_exist_linting
 
 CWD = os.getcwd()
@@ -14,33 +10,9 @@ class WebWebsitePythonLint(TemplateLinter, metaclass=GetLintingFunctionsMeta):
     def __init__(self, path):
         super().__init__(path)
 
-    def lint(self, is_create, skip_external):
+    def lint(self):
         super().lint_project(self, self.methods)
 
-        # Call autopep8, if needed
-        if is_create:
-            print("[blue]Running autopep8 to fix pep8 issues in place")
-            autopep8 = Popen(
-                ["autopep8", self.path, "--recursive", "--in-place", "--pep8-passes", "2000"],
-                universal_newlines=True,
-                shell=False,
-                close_fds=True,
-            )
-            (autopep8_stdout, autopep8_stderr) = autopep8.communicate()
-        elif skip_external:
-            pass
-        elif cookietemple_questionary_or_dot_cookietemple(
-            function="confirm", question="Do you want to run autopep8 to fix pep8 issues?", default="n"
-        ):
-            print("[blue]Running autopep8 to fix pep8 issues in place")
-            autopep8 = Popen(
-                ["autopep8", self.path, "--recursive", "--in-place", "--pep8-passes", "2000"],
-                universal_newlines=True,
-                shell=False,
-                close_fds=True,
-            )
-            (autopep8_stdout, autopep8_stderr) = autopep8.communicate()
-
     def check_sync_section(self) -> bool:
         """
         Check the sync_files_blacklisted section containing every required file!
